//
// Copyright (c) 2022, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;


namespace MindFusion.Diagramming.WinForms.Samples.CS.Reflections
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			Diagram.RegisterClass(typeof(ReflectiveNode), "custom:reflectiveNode", 1);

			diagram.LoadFromString(Properties.Resources.Reflections);

			diagramView.CustomBehavior = new CustomBehavior(diagramView);
            diagram.ShapeNodeStyle.Brush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204));

			diagram.NodeCreated += new EventHandler<NodeEventArgs>(diagram_NodeCreated);
			diagram.NodeDoubleClicked += new EventHandler<NodeEventArgs>(diagram_NodeDoubleClicked);
		}

		private void diagram_NodeDoubleClicked(object sender, NodeEventArgs e)
		{
			ReflectiveNode node = e.Node as ReflectiveNode;
			if (node == null)
				return;

			OpenFileDialog dialog = new OpenFileDialog();
			dialog.Filter = "Image files|*.png;*.bmp;*.gif;*.jpg;*.jpeg|All files|*.*";
			if (dialog.ShowDialog(this) == DialogResult.OK)
			{
				try
				{
					node.Image = Image.FromFile(dialog.FileName);
					node.Transparent = true;
				}
				catch (Exception ex)
				{
					MessageBox.Show(ex.Message);
				}
			}
		}

		private void diagram_NodeCreated(object sender, NodeEventArgs e)
		{
			// If the node is not a reflective node, replace it
			ReflectiveNode rnode = e.Node as ReflectiveNode;
			if (rnode == null)
			{
				ShapeNode node = e.Node as ShapeNode;
				if (node != null)
				{
					rnode = new ReflectiveNode(diagram);
					rnode.Shape = node.Shape;
					rnode.Bounds = node.Bounds;
					diagram.Nodes.Add(rnode);
					diagram.Nodes.Remove(node);
				}
			}
		}
	}
}
